@@ -1,11 +1,5 @@
 open Printf
-open Html5.M
-
-let href uri =
-  a_href (uri_of_string uri)
-
-let a_link url text =
-  a ~a:[a_href (uri_of_string url)] [pcdata text]
+open Tyxml.Html
 
 let page ~title ~subtitle ~headers ~body ~footer =
   let headers =
@@ -20,25 +14,25 @@ let page ~title ~subtitle ~headers ~body ~footer =
     headers in
   html ~a:[a_xmlns `W3_org_1999_xhtml]
     (head
-       (Html5.M.title (pcdata title))
+       (Tyxml.Html.title (txt title))
        headers
     )
-    (Html5.M.body ~a:[a_class ["debian"]] [
-      h1 ~a:[a_id "title"] [pcdata "Ubuntu Release Management"];
+    (Tyxml.Html.body ~a:[a_class ["debian"]] [
+      h1 ~a:[a_id "title"] [txt "Ubuntu Release Management"];
       h2 ~a:[a_id "subtitle"] subtitle;
       div ~a:[a_id "body"] body;
       div ~a:[a_id "footer"] footer
     ])
 
-open Template
+open Ben.Template
 
 let () =
-  Benl_templates.register_template {
+  Ben_frontends.Templates.register_template {
     name = "Ubuntu";
     page;
     intro = [];
     pts = (fun ~src -> sprintf "https://launchpad.net/ubuntu/+source/%s" src);
-    changelog = (fun ~letter ~src ~ver -> sprintf "http://changelogs.ubuntu.com/changelogs/%s/%s_%s/changelog" letter src ver);
+    changelog = (fun ~letter ~src ~ver -> sprintf "https://changelogs.ubuntu.com/changelogs/%s/%s_%s/changelog" letter src ver);
     buildd = (fun ~src ~ver -> sprintf "https://launchpad.net/ubuntu/+source/%s/%s" src ver);
     buildds = (fun ~srcs -> None);
     bugs = (fun ~src -> sprintf "https://bugs.launchpad.net/ubuntu/+source/%s" src);
